package com.yonge.cooleshow.admin.controller;

import com.yonge.cooleshow.biz.dal.entity.Subject;
import com.yonge.cooleshow.biz.dal.queryInfo.SubjectQueryInfo;
import com.yonge.cooleshow.biz.dal.service.SubjectService;
import com.yonge.cooleshow.common.controller.BaseController;
import com.yonge.cooleshow.common.entity.HttpResponseResult;
import com.yonge.toolset.base.page.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.Map;
import java.util.stream.Collectors;

@RequestMapping("${app-config.url.admin:}/subject")
@Api(tags = "声部服务")
@RestController
public class SubjectController extends BaseController {

	@Autowired
	private SubjectService subjectService;

	@ApiOperation(value = "根据声部编号查询声部")
	@GetMapping("/get/{id}")
	@PreAuthorize("@pcs.hasPermissions('subject/get')")
	public HttpResponseResult<Subject> get(@ApiParam(value = "声部编号", required = true) @PathVariable("id") Long id) {
		return succeed(subjectService.get(id));
	}

	@ApiOperation(value = "分页查询声部列表")
	@GetMapping("/queryPage")
	@PreAuthorize("@pcs.hasPermissions('subject/queryPage')")
	public HttpResponseResult<PageInfo<Subject>> queryPage(SubjectQueryInfo queryInfo) {
		PageInfo<Subject> pageInfo = subjectService.queryPage(queryInfo);
		
		if(pageInfo.getRows().size() == 0){
			return succeed(pageInfo);
		}

		Map<Long, Subject> map = subjectService.findBySubjectByIdList(pageInfo.getRows().stream().map(t -> t.getParentSubjectId()).collect(Collectors.toList())).stream()
				.collect(Collectors.toMap(Subject::getId, t -> t));

		pageInfo.getRows().forEach(row -> {
			if(row.getParentSubjectId() != null && row.getParentSubjectId() > 0) {
				row.setParentSubjectName(map.get(row.getParentSubjectId()).getName());
			}
		});
		return succeed(pageInfo);
	}

	@ApiOperation(value = "分页查询声部树状列表")
	@GetMapping("/queryPageTree")
	@PreAuthorize("@pcs.hasPermissions('subject/queryPageTree')")
	public HttpResponseResult<PageInfo<Subject>> queryPageTree(SubjectQueryInfo queryInfo) {
		return succeed(subjectService.queryPageTree(queryInfo));
	}

	@ApiOperation(value = "修改、新增声部")
	@PostMapping("/upset")
	@PreAuthorize("@pcs.hasPermissions('subject/upset')")
	public Object update(@RequestBody Subject subject) {
		subjectService.upSetSubject(subject);
		return succeed();
	}

	/*@ApiOperation(value = "删除指定声部")
	@PostMapping("/delete/{id}")
	@PreAuthorize("@pcs.hasPermissions('subject/delete')")
	public HttpResponseResult<Subject> delete(@ApiParam(value = "声部编号", required = true) @PathVariable("id") Long id) {
		subjectService.deleteById(id);
		return succeed();
	}*/
}
